These functions back the RStudio addins registered by the package. They must be called from an active RStudio source editor. External formatters are configured through the active document's Panache configuration. R code defaults to the arity R package when no R formatter is configured.
Arguments
- config
A TOML path or
NULLfor discovery, as informat_text(). Defaults to thepanache.configR option, allowing a configuration path to be set from.Rprofile.- isolated
Whether to ignore configuration files.
- ...
Named formatting overrides passed to
format_text().